#!/usr/bin/env python3

from keras.models import load_model
import numpy as np
import png
import sys

if __name__ == '__main__':
    if len(sys.argv) < 2:
        raise Exception('Please specify at least one PNG image as argument.')

    # Load trained keras model
    model = load_model('model.hd5')

    # Get image names from arguments
    print('Load images:')
    filename_images = []
    for arg in sys.argv[1:]:
        print('    {}'.format(arg))
        filename_images.append(arg)

    # Load images from files
    images = np.zeros((len(filename_images), 28, 28, 1))
    for i_file, file_ in enumerate(filename_images):
        pngdata = png.Reader(open(file_, 'rb')).asDirect()
        for i_row, row in enumerate(pngdata[2]):
            images[i_file, i_row, :, 0] = row

    # Predict labels for images
    labels = model.predict(images)
    numbers = np.argmax(labels, axis=1)
    print('Predict labels for images:')
    for file_, number in zip(filename_images, numbers):
        print('    {} : {}'.format(file_, number))
