#!/bin/bash

# Be sure that you read this script before executing it
read -p "[WARNING] Have you read the code of this script [y/n]? " -n 1 -r
echo
if ! [[ $REPLY =~ ^[Yy]$ ]]
then
    echo "[ERROR] Read it!"
    exit
fi

# Install Python virtual environment
echo "[INFO] Set up virtual Python environment using Python 3 venv module (python3 >= 3.10 needed)."
python3 -m venv py_venv

# Activate Python virtual environment
echo "[INFO] Activate virtual environment (you have to do this in every new shell!). Now we can install packages via pip locally. You can leave the virtual environment by calling 'deactivate'."
source py_venv/bin/activate

# Upgrade pip to newest version
# NOTE: We fix all package versions so that the results are reproducible.
pip install --upgrade pip

# Install Tensorflow
# NOTE: Keras can be run with either Theano or Tensorflow as backend.
pip install tensorflow=="2.8.0"

# Install Keras (wrapper for Tensorflow) and h5py (optional dependency
# so that we can store our models to file).
pip install keras=="2.8.0" h5py=="3.6.0"

# Some additional dependencies
pip install pypng=="0.0.21"

# Write Keras config
# NOTE: This sets Tensorflow as the default backend for Keras.
mkdir -p ~/.keras/
cp keras.json ~/.keras/

echo "[INFO] Keep in mind: You can activate the virtual environment with all dependencies with 'source py_venv/bin/activate'."
